@@ -12,7 +12,7 @@ use File::Which ();
 # Globals
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK $IMPLEMENTED_BY};
 BEGIN {
-	$VERSION = '0.90_04';
+	$VERSION = '0.92_01';
 
 	# Inherit manually
 	require Exporter;
@@ -27,6 +27,7 @@ BEGIN {
 		my_pictures
 		my_videos
 		my_data
+		my_dist_data
 		users_home
 		users_desktop
 		users_documents
@@ -135,6 +136,35 @@ sub my_data {
 }
 
 
+sub my_dist_data {
+	my $params = ref $_[-1] eq 'HASH' ? pop : {};
+	my $dist   = pop or Carp::croak("The my_dist_data method requires an argument");
+	my $data   = my_data();
+
+        # If datadir is not defined, there's nothing we can do: bail out
+        # and return nothing...	
+	return undef unless defined $data;
+
+        # On traditional unixes, data and config will be resolved as
+        # $HOME. Therefore, we're adding a trailing var/ to prevent dist
+        # config and dist data to conflate.
+	my $var = $data eq home()
+		? File::Spec->catdir( $data, '.perl', 'dist', $dist, 'var' )
+		: File::Spec->catdir( $data, 'Perl',  'dist', $dist );
+
+	# directory exists: return it
+	return $var if -d $var;
+
+	# directory doesn't exist: check if we need to create it...
+	return undef unless $params->{create};
+
+	# user requested directory creation
+	require File::Path;
+	File::Path::mkpath( $var );
+	return $var;
+}
+
+
 
 
 
@@ -187,7 +217,6 @@ sub users_data {
 
 
 
-
 #####################################################################
 # Legacy Methods
 
@@ -285,13 +314,14 @@ File::HomeDir - Find your home and other directories, on any platform
   use File::HomeDir;
   
   # Modern Interface (Current User)
-  $home    = File::HomeDir->my_home;
-  $desktop = File::HomeDir->my_desktop;
-  $docs    = File::HomeDir->my_documents;
-  $music   = File::HomeDir->my_music;
-  $pics    = File::HomeDir->my_pictures;
-  $videos  = File::HomeDir->my_videos;
-  $data    = File::HomeDir->my_data;
+  $home     = File::HomeDir->my_home;
+  $desktop  = File::HomeDir->my_desktop;
+  $docs     = File::HomeDir->my_documents;
+  $music    = File::HomeDir->my_music;
+  $pics     = File::HomeDir->my_pictures;
+  $videos   = File::HomeDir->my_videos;
+  $data     = File::HomeDir->my_data;
+  $dist     = File::HomeDir->my_dist_data('File-HomeDir');
   
   # Modern Interface (Other Users)
   $home    = File::HomeDir->users_home('foo');
@@ -306,7 +336,7 @@ File::HomeDir - Find your home and other directories, on any platform
   print "My dir is ", home(), " and root's is ", home('root'), "\n";
   print "My dir is $~{''} and root's is $~{root}\n";
   # These both print the same thing, something like:
-  #  "My dir is /home/user/mojo and root's is /"
+  # "My dir is /home/user/mojo and root's is /"
 
 =head1 DESCRIPTION
 
@@ -464,7 +494,7 @@ user.
 Generally an application would create a subdirectory such as C<.foo>,
 beneath this directory, and store its data there. By creating your
 directory this way, you get an accurate result on the maximum number
-of platforms.
+of platforms. But see the documentation about C<my_dist_data()> below.
 
 For example, on Unix you get C<~/.foo> and on Win32 you get
 C<~/Local Settings/Application Data/.foo>
@@ -472,6 +502,40 @@ C<~/Local Settings/Application Data/.foo>
 Returns the directory path as a string, C<undef> if the current user
 does not have a data directory, or dies on error.
 
+=head2 my_dist_data
+
+  File::HomeDir->my_dist_data( $dist [, \%params] );
+  
+  # For example...
+  
+  File::HomeDir->my_dist_data( 'File-HomeDir' );
+  File::HomeDir->my_dist_data( 'File-HomeDir', { create => 1 } );
+
+The C<my_dist_data> method takes a distribution name as argument and
+returns an application-specific directory where they should store their
+internal data.
+
+This directory will be of course a subdirectory of C<my_data>. Platforms
+supporting data-specific directories will use C<DATA_DIR/perl/dist/Dist-Name>,
+following the traditional DATA / vendor / application split. If the C<my_data>
+directory is the user's homedir, C<my_dist_data> will be in
+C<~/.perl/dist/Dist-Name/var> (and thus be hidden on all Unixes).
+
+The optional last argument is a hash reference to tweak the method
+behaviour. The following hash keys are recognized:
+
+=over 4
+
+=item * create
+
+Passing a true value to this key will force the creation of the
+directory if it doesn't exist (remember that C<File::HomeDir>'s policy
+is to return C<undef> if the directory doesn't exist).
+
+Defaults to false, meaning no automatic creation of directory.
+
+=back
+
 =head2 users_home
 
   $home = File::HomeDir->users_home('foo');
